@@ -5,12 +5,16 @@ import sys
 import re
 from llvd.app import App
 from llvd import config
+from llvd.process_io import parse_cookie_file
+
 
 BOLD = "\033[1m"  # Makes the text bold
 RED_COLOR = "\u001b[31m"  # Makes the text red
 
 
 @click.command()
+@click.option('--cookies', is_flag=True,
+              prompt='Do you want to login with cookies?')
 @click.option("--resolution", "-r",
               default='720',
               help='Video resolution can either be 360, 540 or 720. 720 is the default')
@@ -18,7 +22,7 @@ RED_COLOR = "\u001b[31m"  # Makes the text red
               is_flag=True,
               help="Download subtitles")
 @click.option("--course", "-c", help="Example: 'Java 8 Essential'")
-def main(course, resolution, caption):
+def main(cookies, course, resolution, caption):
     """
     Linkedin learning video downloader cli tool
 
@@ -33,8 +37,17 @@ def main(course, resolution, caption):
     course_slug = course.replace(" ", "-").replace(":-", "-").replace(
         "-&", ""
     ).replace(".", "-")
-    email = click.prompt("Please enter your Linkedin email address")
-    password = click.prompt("Enter your Linkedin Password", hide_input=True)
 
-    llvd = App(email, password, course_slug, resolution, caption)
-    llvd.run()
+    email = ""
+    password = ""
+    if cookies:
+        cookie_dict = parse_cookie_file()
+        llvd = App(email, password, course_slug, resolution, caption)
+        llvd.run(cookie_dict)
+    else:
+        email = click.prompt("Please enter your Linkedin email address")
+        password = click.prompt(
+            "Enter your Linkedin Password", hide_input=True)
+
+        llvd = App(email, password, course_slug, resolution, caption)
+        llvd.run()
